==> yabause_0.9.6.orig.tar.gz: yabause-0.9.6/src/wii/keys.h <==
/*  Copyright 2008 Theo Berkau

    This file is part of Yabause.

    Yabause is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Yabause is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Yabause; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef KEYS_H
#define KEYS_H

#define KEY_A				0x04
#define KEY_B				0x05
#define KEY_C				0x06
#define KEY_D				0x07
#define KEY_E				0x08
#define KEY_F				0x09
#define KEY_G				0x0a
#define KEY_H				0x0b
#define KEY_I				0x0c
#define KEY_J				0x0d
#define KEY_K				0x0e
#define KEY_L				0x0f
#define KEY_M				0x10
#define KEY_N				0x11
#define KEY_O				0x12
#define KEY_P				0x13
#define KEY_Q				0x14
#define KEY_R				0x15
#define KEY_S				0x16
#define KEY_T				0x17
#define KEY_U				0x18
#define KEY_V				0x19
#define KEY_W				0x1a
#define KEY_X				0x1b
#define KEY_Y				0x1c
#define KEY_Z				0x1d
#define KEY_1				0x1f
#define KEY_2				0x20
#define KEY_3				0x21
#define KEY_4				0x22
#define KEY_5				0x23
#define KEY_6				0x24
#define KEY_7				0x25
#define KEY_8				0x26
#define KEY_9				0x27
#define KEY_ENTER			0x28
#define KEY_ESCAPE			0x29
#define KEY_BACKSPACE		0x2a
#define KEY_TAB				0x2b
#define KEY_SPACE			0x2c
#define KEY_MINUS			0x2d
#define KEY_EQUAL			0x2e
#define KEY_LEFTBRACKET		0x2f
#define KEY_RIGHTBRACKET	0x30
#define KEY_UNKNOWN			0x31
#define KEY_LEFTBACKSLASH	0x32
#define KEY_SEMICOLON		0x33
#define KEY_QUOTE			0x34
#define KEY_TILDE			0x35
#define KEY_COMMA			0x36
#define KEY_PERIOD			0x37
#define KEY_SLASH			0x38
#define KEY_CAPSLOCK		0x39
#define KEY_F1				0x3a
#define KEY_F2				0x3b
#define KEY_F3				0x3c
#define KEY_F4				0x3d
#define KEY_F5				0x3e
#define KEY_F6				0x3f
#define KEY_F7				0x40
#define KEY_F8				0x41
#define KEY_F9				0x42
#define KEY_F10				0x43
#define KEY_F11				0x44
#define KEY_F12				0x45
#define KEY_PRINTSCREEN		0x46
#define KEY_SCROLLLOCK		0x47
#define KEY_PAUSE			0x48
#define KEY_INSERT			0x49
#define KEY_HOME			0x4a
#define KEY_PGUP			0x4b
#define KEY_DELETE			0x4c
#define KEY_END				0x4d
#define KEY_PGDN			0x4e
#define KEY_RIGHT			0x4f
#define KEY_LEFT			0x50
#define KEY_DOWN			0x51
#define KEY_UP				0x52
#define KEY_NUMLOCK			0x53
#define KEY_NUMPADSLASH		0x54
#define KEY_NUMPADASTERISK	0x55
#define KEY_NUMPADMINUS		0x56
#define KEY_NUMPADPLUS		0x57
#define KEY_NUMPADENTER		0x58
#define KEY_NUMPAD1			0x59
#define KEY_NUMPAD2			0x5a
#define KEY_NUMPAD3			0x5b
#define KEY_NUMPAD4			0x5c
#define KEY_NUMPAD5			0x5d
#define KEY_NUMPAD6			0x5e
#define KEY_NUMPAD7			0x5f
#define KEY_NUMPAD8			0x60
#define KEY_NUMPAD9			0x61
#define KEY_NUMPAD0			0x62
#define KEY_NUMPADPERIOD	0x63
#define KEY_RIGHTBACKSLASH	0x64
#define KEY_MENU			0x65

#endif

==> yabause_0.9.10.orig.tar.gz: yabause-0.9.10/src/wii/keys.h <==
/*  Copyright 2008 Theo Berkau

    This file is part of Yabause.

    Yabause is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    Yabause is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Yabause; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
*/
#ifndef KEYS_H
#define KEYS_H

#define KEY_A				0x04
#define KEY_B				0x05
#define KEY_C				0x06
#define KEY_D				0x07
#define KEY_E				0x08
#define KEY_F				0x09
#define KEY_G				0x0a
#define KEY_H				0x0b
#define KEY_I				0x0c
#define KEY_J				0x0d
#define KEY_K				0x0e
#define KEY_L				0x0f
#define KEY_M				0x10
#define KEY_N				0x11
#define KEY_O				0x12
#define KEY_P				0x13
#define KEY_Q				0x14
#define KEY_R				0x15
#define KEY_S				0x16
#define KEY_T				0x17
#define KEY_U				0x18
#define KEY_V				0x19
#define KEY_W				0x1a
#define KEY_X				0x1b
#define KEY_Y				0x1c
#define KEY_Z				0x1d
#define KEY_1				0x1f
#define KEY_2				0x20
#define KEY_3				0x21
#define KEY_4				0x22
#define KEY_5				0x23
#define KEY_6				0x24
#define KEY_7				0x25
#define KEY_8				0x26
#define KEY_9				0x27
#define KEY_ENTER			0x28
#define KEY_ESCAPE			0x29
#define KEY_BACKSPACE		0x2a
#define KEY_TAB				0x2b
#define KEY_SPACE			0x2c
#define KEY_MINUS			0x2d
#define KEY_EQUAL			0x2e
#define KEY_LEFTBRACKET		0x2f
#define KEY_RIGHTBRACKET	0x30
#define KEY_UNKNOWN			0x31
#define KEY_LEFTBACKSLASH	0x32
#define KEY_SEMICOLON		0x33
#define KEY_QUOTE			0x34
#define KEY_TILDE			0x35
#define KEY_COMMA			0x36
#define KEY_PERIOD			0x37
#define KEY_SLASH			0x38
#define KEY_CAPSLOCK		0x39
#define KEY_F1				0x3a
#define KEY_F2				0x3b
#define KEY_F3				0x3c
#define KEY_F4				0x3d
#define KEY_F5				0x3e
#define KEY_F6				0x3f
#define KEY_F7				0x40
#define KEY_F8				0x41
#define KEY_F9				0x42
#define KEY_F10				0x43
#define KEY_F11				0x44
#define KEY_F12				0x45
#define KEY_PRINTSCREEN		0x46
#define KEY_SCROLLLOCK		0x47
#define KEY_PAUSE			0x48
#define KEY_INSERT			0x49
#define KEY_HOME			0x4a
#define KEY_PGUP			0x4b
#define KEY_DELETE			0x4c
#define KEY_END				0x4d
#define KEY_PGDN			0x4e
#define KEY_RIGHT			0x4f
#define KEY_LEFT			0x50
#define KEY_DOWN			0x51
#define KEY_UP				0x52
#define KEY_NUMLOCK			0x53
#define KEY_NUMPADSLASH		0x54
#define KEY_NUMPADASTERISK	0x55
#define KEY_NUMPADMINUS		0x56
#define KEY_NUMPADPLUS		0x57
#define KEY_NUMPADENTER		0x58
#define KEY_NUMPAD1			0x59
#define KEY_NUMPAD2			0x5a
#define KEY_NUMPAD3			0x5b
#define KEY_NUMPAD4			0x5c
#define KEY_NUMPAD5			0x5d
#define KEY_NUMPAD6			0x5e
#define KEY_NUMPAD7			0x5f
#define KEY_NUMPAD8			0x60
#define KEY_NUMPAD9			0x61
#define KEY_NUMPAD0			0x62
#define KEY_NUMPADPERIOD	0x63
#define KEY_RIGHTBACKSLASH	0x64
#define KEY_MENU			0x65

#endif
